summaryrefslogtreecommitdiffstats
path: root/kdecore/kaccelmanager_private.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdecore/kaccelmanager_private.h')
-rw-r--r--kdecore/kaccelmanager_private.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdecore/kaccelmanager_private.h b/kdecore/kaccelmanager_private.h
index cd3f30a12..fbb5d1857 100644
--- a/kdecore/kaccelmanager_private.h
+++ b/kdecore/kaccelmanager_private.h
@@ -32,7 +32,7 @@ class TQWidgetStack;
/**
* A string class handling accelerators.
*
- * This class tqcontains a string and knowledge about accelerators.
+ * This class contains a string and knowledge about accelerators.
* It keeps a list weights, telling how valuable each character
* would be as an accelerator.
*
@@ -81,7 +81,7 @@ typedef TQValueList<KAccelString> KAccelStringList;
/**
- * This class encapsulates the algorithm tqfinding the 'best'
+ * This class encapsulates the algorithm finding the 'best'
* distribution of accelerators in a hierarchy of widgets.
*
* @author Matthias Hoelzer-Kluepfel <mhk@kde.org>
@@ -113,8 +113,8 @@ public:
STANDARD_ACCEL = 300
};
- /// Method to call to tqfind the best distribution of accelerators.
- static void tqfindAccelerators(KAccelStringList &result, TQString &used);
+ /// Method to call to find the best distribution of accelerators.
+ static void findAccelerators(KAccelStringList &result, TQString &used);
};
@@ -131,7 +131,7 @@ class TQPopupMenu;
* @author Matthias Hoelzer-Kluepfel <mhk@kde.org>
*/
-class KPopupAccelManager : public TQObject
+class KPopupAccelManager : public QObject
{
Q_OBJECT
@@ -154,7 +154,7 @@ private:
void calculateAccelerators();
- void tqfindMenuEntries(KAccelStringList &list);
+ void findMenuEntries(KAccelStringList &list);
void setMenuEntries(const KAccelStringList &list);
TQPopupMenu *m_popup;
@@ -164,7 +164,7 @@ private:
};
-class QWidgetStackAccelManager : public TQObject
+class QWidgetStackAccelManager : public QObject
{
Q_OBJECT